@@ -14,7 +14,8 @@ class APIException(fastapi.exceptions.HTTPException):
             error_code: str | None = APIErrorCodes.unknown_error,
             error_specification_code: str | None = None,
             error_description: str | None = None,
-            error_data: dict[str, Any] | None = None
+            error_data: dict[str, Any] | None = None,
+            kwargs_: dict[str, Any] | None = None
     ):
         self.status_code = status_code
         self.error_code = error_code
@@ -23,6 +24,9 @@ class APIException(fastapi.exceptions.HTTPException):
         if error_data is None:
             error_data = {}
         self.error_data = error_data
+        if kwargs_ is None:
+            kwargs_ = None
+        self.kwargs_ = kwargs_
 
         self.error_common_so = ErrorCommonSO(
             has_error=True,
